pub fn features() -> impl Iterator<Item = (&'static str, bool)>Available on crate feature
full only.Expand description
Returns an iterator over feature names and their support on the current system
pub fn features() -> impl Iterator<Item = (&'static str, bool)>full only.Returns an iterator over feature names and their support on the current system